::: beignet.datasets.RandomRotationDataset
::: beignet.datasets.RandomEulerAngleDataset
::: beignet.datasets.RandomQuaternionDataset
::: beignet.datasets.RandomRotationMatrixDataset
::: beignet.datasets.RandomRotationVectorDataset
